@@ -2,7 +2,6 @@ import { JupyterFrontEnd, JupyterFrontEndPlugin, ILayoutRestorer, ILabShell } fr
 import { IToolbarWidgetRegistry, ReactWidget } from '@jupyterlab/apputils';
 import { ITranslator } from '@jupyterlab/translation';
 import { TransformerLeftPanel } from './widgets/TransformerLeftPanel';
-import { INotebookTracker } from '@jupyterlab/notebook';
 import * as React from 'react';
 import '../style/index.css';
 import { ISettingRegistry } from '@jupyterlab/settingregistry';
@@ -11,7 +10,7 @@ import { SETTINGS_ID } from './settings';
 let transformerSettings: ISettingRegistry.ISettings;
 export default {
     id: 'modeldeploy-proxy-labextension:leftpanel',
-    requires: [ILabShell, ISettingRegistry, ILayoutRestorer, INotebookTracker, IToolbarWidgetRegistry],
+    requires: [ILabShell, ISettingRegistry, ILayoutRestorer, IToolbarWidgetRegistry],
     optional: [ITranslator],
     autoStart: true,
     activate: async (
@@ -19,7 +18,6 @@ export default {
         labShell: ILabShell,
         settingRegistry: ISettingRegistry,
         restorer: ILayoutRestorer,
-        tracker: INotebookTracker,
         toolbarRegistry: IToolbarWidgetRegistry,
         translator: ITranslator,
     ) => {
@@ -36,7 +34,6 @@ export default {
         app.started.then(() => {
             widget = ReactWidget.create(
                 <TransformerLeftPanel
-                  tracker={tracker}
                   transformerSettings={transformerSettings}
                 />,
             );
