@@ -40,7 +40,6 @@ const handleNotebookChanged = async (notebookTracker: INotebookTracker, notebook
         });
 
         notebookPanel.model.cells.changed.connect((cells: IObservableUndoableList<ICellModel>, change: IObservableList.IChangedArgs<ICellModel>) => {
-            console.log("Cell change now...");
             makeCellTransformerWidgets(notebookPanel);
         });
 
@@ -106,6 +105,15 @@ const createCellTransformerWidgets = (cellId: string, notebookPanel: NotebookPan
     );
 }
 
+export const showCurrentActiveCellTransformerWidget = (notebookPanel: NotebookPanel) => {
+    let notebook: Notebook = notebookPanel.content;
+    let cellElement: HTMLElement = notebook.node.childNodes[notebook.activeCellIndex] as HTMLElement;
+    let transformerMetaChip: HTMLElement = cellElement.querySelector('.cell-transformer-widget .transformer-meta-chip') as HTMLElement;
+    if(transformerMetaChip) {
+        transformerMetaChip.click();
+    }
+}
+
 export default {
     id: 'modeldeploy-proxy-labextension:notebook',
     requires: [ISettingRegistry, INotebookTracker, IDocumentManager],
